==> haskell-numtype-dk-0.5.0.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numtype-dk.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numtype-dk
version:              0.5.0.3
visibility:           public
id:                   numtype-dk-0.5.0.3-LX884BCeD4w1vUYdJk4Ii4
key:                  numtype-dk-0.5.0.3-LX884BCeD4w1vUYdJk4Ii4
license:              BSD-3-Clause
copyright:            Bjorn Buckwalter 2012-2021
maintainer:           bjorn@buckwalter.se
author:               Bjorn Buckwalter
stability:            provisional
homepage:             https://github.com/bjornbm/numtype-dk
synopsis:
    Type-level integers, using TypeNats, Data
    Kinds, and Closed Type Families.

description:
    This package provides type level representations of the
    (positive and negative) integers and basic operations (addition,
    subtraction, multiplication, division, exponentiation) on these.
    The numtype-dk package differs from the numtype package in that
    the NumTypes are implemented using Data Kinds, TypeNats, and
    Closed Type Families rather than Functional Dependencies.
    Requires GHC 7.8 or later.

category:             Math
abi:                  20012bed93cbcab79f8800025b3cfb01
exposed:              True
exposed-modules:      Numeric.NumType.DK.Integers
hidden-modules:       Numeric.NumType.DK.Naturals
import-dirs:          /usr/lib/ghc-9.0.2/site-local/numtype-dk-0.5.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/numtype-dk-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/numtype-dk-0.5.0.3
hs-libraries:         HSnumtype-dk-0.5.0.3-LX884BCeD4w1vUYdJk4Ii4
depends:              base-4.15.1.0
haddock-interfaces:   /usr/share/doc/haskell-numtype-dk/html/numtype-dk.haddock
haddock-html:         /usr/share/doc/haskell-numtype-dk/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numtype-dk-0.5.0.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numtype-dk.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numtype-dk
version:              0.5.0.3
visibility:           public
id:                   numtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5
key:                  numtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5
license:              BSD-3-Clause
copyright:            Bjorn Buckwalter 2012-2021
maintainer:           bjorn@buckwalter.se
author:               Bjorn Buckwalter
stability:            provisional
homepage:             https://github.com/bjornbm/numtype-dk
synopsis:
    Type-level integers, using TypeNats, Data
    Kinds, and Closed Type Families.

description:
    This package provides type level representations of the
    (positive and negative) integers and basic operations (addition,
    subtraction, multiplication, division, exponentiation) on these.
    The numtype-dk package differs from the numtype package in that
    the NumTypes are implemented using Data Kinds, TypeNats, and
    Closed Type Families rather than Functional Dependencies.
    Requires GHC 7.8 or later.

category:             Math
abi:                  e254e7e267ac82aff87b889ae1d871f6
exposed:              True
exposed-modules:      Numeric.NumType.DK.Integers
hidden-modules:       Numeric.NumType.DK.Naturals
import-dirs:          /usr/lib/ghc-9.2.8/site-local/numtype-dk-0.5.0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/numtype-dk-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numtype-dk
hs-libraries:         HSnumtype-dk-0.5.0.3-89eY94N4xeAfNXJQwHHE5
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-numtype-dk/html/numtype-dk.haddock
haddock-html:         /usr/share/doc/haskell-numtype-dk/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
